import 'package:hgg_base/src/utils/x_log.dart';

extension ExMap on Map {
  static bool showMapLog = false;

  static void _log(Object? object, [bool showLog = true]) {
    if (showMapLog && showLog) {
      XLog.d2(object);
    }
  }

  /// 获取 value 转 string
  String s(String key, {String defaultValue = '', bool showLog = true}) {
    if (!containsKey(key)) {
      _log('当前map不存在 key:[$key]', showLog);
      return defaultValue;
    }
    final value = this[key];
    if (value is String) return value;
    if (value == null) {
      _log('[$key]的值为 null', showLog);
      return defaultValue;
    }
    _log('${value.runtimeType} [$key]=$value => String:$value', showLog);
    return value.toString();
  }

  String s0(String key, {String defaultValue = ''}) {
    return s(key, defaultValue: defaultValue, showLog: false);
  }

  /// 获取 value 转 double
  double d(String key, {double defaultValue = 0, bool showLog = true}) {
    if (!containsKey(key)) {
      _log('当前map不存在 key:[$key]', showLog);
      return defaultValue;
    }
    final value = this[key];
    if (value is double) return value;
    if (value is int) return value.toDouble();
    if (value == null) {
      _log('[$key]的值为 null', showLog);
      return defaultValue;
    }
    final other = double.tryParse(value.toString()) ?? defaultValue;
    _log('${value.runtimeType} [$key]=$value => double:$other', showLog);
    return other;
  }

  double d0(String key, {double defaultValue = 0}) {
    return d(key, defaultValue: defaultValue, showLog: false);
  }

  /// 获取 value 转 int
  int i(String key, {int defaultValue = 0, bool showLog = true}) {
    if (!containsKey(key)) {
      _log('当前map不存在 key:[$key]', showLog);
      return defaultValue;
    }
    final value = this[key];
    if (value is int) return value;
    if (value is double) return value.toInt();
    if (value == null) {
      _log('[$key]的值为 null', showLog);
      return defaultValue;
    }
    final other = int.tryParse(value.toString()) ?? defaultValue;
    _log('${value.runtimeType} [$key]=$value => int:$other', showLog);
    return other;
  }

  int i0(String key, {int defaultValue = 0}) {
    return i(key, defaultValue: defaultValue, showLog: false);
  }

  /// 获取 value 转 bool
  bool b(String key, {bool defaultValue = false, bool showLog = true}) {
    if (!containsKey(key)) {
      _log('当前map不存在 key:[$key]', showLog);
      return defaultValue;
    }
    final value = this[key];
    if (value is bool) return value;
    _log('${value.runtimeType} [$key]=$value => bool:$defaultValue', showLog);
    return defaultValue;
  }

  bool b0(String key, {bool defaultValue = false}) {
    return b(key, defaultValue: defaultValue, showLog: false);
  }

  /// 获取 value 转 bool
  Map m(String key, {Map defaultValue = const {}, bool showLog = true}) {
    if (!containsKey(key)) {
      _log('当前map不存在 key:[$key]', showLog);
      return defaultValue;
    }
    final value = this[key];
    if (value is Map) return value;
    _log('${value.runtimeType} [$key]=$value => map:$defaultValue', showLog);
    return defaultValue;
  }

  Map m0(String key, {Map defaultValue = const {}}) {
    return m(key, defaultValue: defaultValue, showLog: false);
  }

  /// 获取 value 转 bool
  List l(String key, {List defaultValue = const [], bool showLog = true}) {
    if (!containsKey(key)) {
      _log('当前map不存在 key:[$key]', showLog);
      return defaultValue;
    }
    final value = this[key];
    if (value is List) return value;
    _log('${value.runtimeType} [$key]=$value => list:$defaultValue', showLog);
    return defaultValue;
  }

  List l0(String key, {List defaultValue = const []}) {
    return l(key, defaultValue: defaultValue, showLog: false);
  }
}
