import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:hgg_base/src/utils/x_size.dart';

/// 将 Padding 属性添加到小部件
extension WidgetPaddingX on Widget {
  Widget paddingAll(double all) => Padding(
        padding: P.all(all),
        child: this,
      );

  Widget paddingHv(double horizontal, double vertical) => Padding(
        padding: P.hv(horizontal: horizontal, vertical: vertical),
        child: this,
      );

  Widget paddingHorizontal(double horizontal) => Padding(
        padding: P.hv(horizontal: horizontal),
        child: this,
      );

  Widget paddingVertical(double vertical) => Padding(
        padding: P.hv(vertical: vertical),
        child: this,
      );

  Widget paddingOnly({
    double left = 0.0,
    double top = 0.0,
    double right = 0.0,
    double bottom = 0.0,
  }) =>
      Padding(
        padding: P.only(top: top, left: left, right: right, bottom: bottom),
        child: this,
      );

  Widget paddingTop(double top) => Padding(
        padding: P.only(top: top),
        child: this,
      );

  Widget paddingBottom(double bottom) => Padding(
        padding: P.only(bottom: bottom),
        child: this,
      );

  Widget paddingLeft(double left) => Padding(
        padding: P.only(left: left),
        child: this,
      );

  Widget paddingRight(double right) => Padding(
        padding: P.only(right: right),
        child: this,
      );
}

/// 将 color 属性添加到小部件
extension WidgetColorX on Widget {
  Widget get yellow => ColoredBox(
        color: Colors.yellow,
        child: this,
      );

  Widget get blue => ColoredBox(
        color: Colors.blue,
        child: this,
      );

  Widget get red => ColoredBox(
        color: Colors.red,
        child: this,
      );
}
