import 'package:dio/dio.dart';

import '../../hgg_base.dart';
import 'resp_data.dart';

///API拦截器
class ApiOnResponse extends InterceptorsWrapper {
  final bool showLog;

  ApiOnResponse({
    this.showLog = false,
    required this.mapToRespData,
    required this.doShowErrorMsg,
  });

  final RespData Function(Map) mapToRespData;
  final Function(String) doShowErrorMsg;

  @override
  void onResponse(Response response, ResponseInterceptorHandler handler) {
    // 请求 url
    var requestUrl = response.requestOptions.uri.toString();
    requestUrl = Uri.decodeComponent(requestUrl);
    // 响应处理
    if (response.data is Map) {
      Map data = response.data;
      RespData respData = mapToRespData(data);

      if (respData.code == null && respData.message.isEmpty) {
        XLog.json(response.data, 'Quick请求url:$requestUrl');
        return handler.resolve(response);
      }

      if (respData.success) {
        if (!requestUrl.contains('hideLog') && showLog) {
          XLog.json(response.data, '请求url:$requestUrl');
        }
        if (respData.data != null) response.data = respData.data;
        return handler.resolve(response);
      } else {
        // 需要登录,  用接口内部 code ,确定未登录
        if (respData.code.toString() == respData.unLoginCode.toString()) {
          respData.onUnLogin?.call();
        }

        if (!requestUrl.contains('hideMsg') &&
            U.isNotEmpty(respData.message) &&
            respData.message.length < 50) {
          //显示请求错误的信息
          doShowErrorMsg(respData.message);
        }
        XLog.e(response.data, '请求url:$requestUrl');
        return handler.reject(DioError(
          requestOptions: response.requestOptions,
          error: respData.message,
        ));
      }
    } else {
      XLog.e(response.data, '请求的结果不是jsonMap');
      return handler.resolve(response);
    }
  }
}
